==> haskell-network-run-0.3.1-19.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-run.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-run
version:              0.3.1
visibility:           public
id:                   network-run-0.3.1-15CXkFunfg0BSeTsp1yI46
key:                  network-run-0.3.1-15CXkFunfg0BSeTsp1yI46
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  b04d7925b8aa80e20968eb915ed3615a
exposed:              True
exposed-modules:
    Network.Run.TCP Network.Run.TCP.Timeout Network.Run.UDP

hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-run-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-run-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-run-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-run
hs-libraries:         HSnetwork-run-0.3.1-15CXkFunfg0BSeTsp1yI46
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    time-manager-0.0.1-JLWrHaSTuhLLhgQpXh0DRR

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-run-0.3.1-20-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-run.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-run
version:              0.3.1
visibility:           public
id:                   network-run-0.3.1-2xjBLHgRAj99cypR1FcNZe
key:                  network-run-0.3.1-2xjBLHgRAj99cypR1FcNZe
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  5ec9ae5c2120ca6df194febba379550b
exposed:              True
exposed-modules:
    Network.Run.TCP Network.Run.TCP.Timeout Network.Run.UDP

hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-run-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-run-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-run-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-run
hs-libraries:         HSnetwork-run-0.3.1-2xjBLHgRAj99cypR1FcNZe
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    time-manager-0.0.1-J7X2oj44VWZ1BlIeM6DdG7

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
